@@ -44,9 +44,10 @@
 #include "prefs.h"
 #include "Option.h"
 #include "RequestGroupMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
-#include "ServerStatMan.h"
+#include "FileEntry.h"
+#include "SocketRecvBuffer.h"
+#include "LogFactory.h"
+#include "wallclock.h"
 
 namespace aria2 {
 
@@ -55,7 +56,9 @@ CreateRequestCommand::CreateRequestCommand(cuid_t cuid,
                                            DownloadEngine* e):
   AbstractCommand
   (cuid, SharedHandle<Request>(), SharedHandle<FileEntry>(), requestGroup, e,
-   SharedHandle<SocketCore>(), false)
+   SharedHandle<SocketCore>(),
+   SharedHandle<SocketRecvBuffer>(),
+   false)
 {
   setStatus(Command::STATUS_ONESHOT_REALTIME);
   disableReadCheckSocket();
@@ -87,11 +90,16 @@ bool CreateRequestCommand::executeInternal()
                                  getOption()->getAsBool(PREF_USE_HEAD)) ||
                                 getOption()->getAsBool(PREF_DRY_RUN)?
                                 Request::METHOD_HEAD:Request::METHOD_GET));
-  if(getRequest().isNull()) {
-    if(!getSegmentMan().isNull()) {
+  if(!getRequest()) {
+    if(getSegmentMan()) {
       getSegmentMan()->ignoreSegmentFor(getFileEntry());
     }
     throw DL_ABORT_EX("No URI available.");
+  } else if(getRequest()->getWakeTime() > global::wallclock) {
+    A2_LOG_DEBUG("This request object is still sleeping.");
+    getFileEntry()->poolRequest(getRequest());
+    getDownloadEngine()->addCommand(this);
+    return false;
   }
 
   Command* command =
